@@ -1,6 +1,6 @@
 # **************************************************************************
 # *
-# * Authors:     Federico P. de Isidro Gomez (fp.deisidro@cnb.csi.es) [1]
+# * Authors:     Federico P. de Isidro Gomez (fp.deisidro@cnb.csic.es) [1]
 # *
 # * [1] Centro Nacional de Biotecnologia, CSIC, Spain
 # *
@@ -28,9 +28,9 @@ import pwem
 
 from .constants import NOVACTF_HOME
 
-__version__ = '3.0.2'
+__version__ = '3.0.4'
 _logo = ""
-_references = []
+_references = ["Turonova2017"]
 
 
 class Plugin(pwem.Plugin):
